==> kie-wb-common-7.0.0.Final-project-sources.tar.gz: kie-wb-common-7.0.0.Final/kie-wb-common-stunner/kie-wb-common-stunner-extensions/kie-wb-common-stunner-lienzo-extensions/src/main/java/org/kie/workbench/common/stunner/lienzo/primitive/PrimitiveDragProxy.java <==
/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.lienzo.primitive;

import com.ait.lienzo.client.core.shape.IPrimitive;
import com.ait.lienzo.client.core.shape.Layer;

public class PrimitiveDragProxy extends AbstractDragProxy<IPrimitive<?>> {

    public PrimitiveDragProxy(final Layer layer,
                              final IPrimitive<?> shape,
                              final int x,
                              final int y,
                              final int timeout,
                              final Callback callback) {
        super(layer,
              shape,
              x,
              y,
              timeout,
              callback);
    }

    @Override
    protected void addToLayer(final Layer layer,
                              final IPrimitive<?> shape) {
        layer.add(shape);
    }

    @Override
    protected void removeFromLayer(final Layer layer,
                                   final IPrimitive<?> shape) {
        shape.removeFromParent();
    }

    @Override
    protected void setX(final IPrimitive<?> shape,
                        final int x) {
        shape.setX(x);
    }

    @Override
    protected void setY(final IPrimitive<?> shape,
                        final int y) {
        shape.setY(y);
    }
}

==> kie-wb-common-7.24.0.Final-project-sources.tar.gz: kie-wb-common-7.24.0.Final/kie-wb-common-stunner/kie-wb-common-stunner-extensions/kie-wb-common-stunner-lienzo-extensions/src/main/java/org/kie/workbench/common/stunner/lienzo/primitive/PrimitiveDragProxy.java <==
/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.lienzo.primitive;

import com.ait.lienzo.client.core.shape.IPrimitive;
import com.ait.lienzo.client.core.shape.Layer;

public class PrimitiveDragProxy extends AbstractDragProxy<IPrimitive<?>> {

    public PrimitiveDragProxy(final Layer layer,
                              final IPrimitive<?> shape,
                              final int x,
                              final int y,
                              final int timeout,
                              final Callback callback) {
        super(layer,
              shape,
              x,
              y,
              timeout,
              callback);
    }

    @Override
    protected void addToLayer(final Layer layer,
                              final IPrimitive<?> shape) {
        layer.add(shape);
    }

    @Override
    protected void removeFromLayer(final Layer layer,
                                   final IPrimitive<?> shape) {
        shape.removeFromParent();
    }

    @Override
    protected void setLocation(IPrimitive<?> shape,
                               int x,
                               int y) {
        shape.setX(x).setY(y);
    }
}
